==> igniteui-react-charts-16.6.8.tgz: package/ES2015/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core/ES2015/type";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Color } from "igniteui-react-core/ES2015/Color";
/**
 * @hidden
 */
export class PointSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.ab = PointSeries.$;
    }
    bf() {
        return new PointSeriesView(this);
    }
    im(a) {
        super.im(a);
        this.qa = a;
    }
    dg(a, b) {
        let c = this.le(this.lh(a), true, false);
        if (this.lx(a, b)) {
            return true;
        }
        return false;
    }
    is(a, b, c, d) {
        super.is(a, b, c, d);
    }
    get_cy() {
        return false;
    }
    get useHighMarkerFidelity() {
        return this.nv;
    }
}
PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
/**
 * @hidden
 */
export class PointSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.c6 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.by.lu = 2;
            this.e.bj = 4;
        }
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.k3 = a;
        this.e.es = 3;
        this.e.et = 2;
        this.e.eu = 2;
        this.e.dt = false;
    }
}
PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);

==> igniteui-react-charts-16.11.1.tgz: package/ES2015/PointSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { HorizontalAnchoredCategorySeries } from "./HorizontalAnchoredCategorySeries";
import { markType } from "igniteui-react-core/ES2015/type";
import { AnchoredCategorySeriesView } from "./AnchoredCategorySeriesView";
import { Color } from "igniteui-react-core/ES2015/Color";
/**
 * @hidden
 */
export class PointSeries extends HorizontalAnchoredCategorySeries {
    constructor() {
        super();
        this.ab = PointSeries.$;
    }
    bf() {
        return new PointSeriesView(this);
    }
    iu(a) {
        super.iu(a);
        this.qh = a;
    }
    dh(a, b) {
        let c = this.ll(this.lo(a), true, false);
        if (this.l4(a, b)) {
            return true;
        }
        return false;
    }
    iz(a, b, c, d) {
        super.iz(a, b, c, d);
    }
    get_cy() {
        return false;
    }
    get useHighMarkerFidelity() {
        return this.n2;
    }
}
PointSeries.$t = markType(PointSeries, 'PointSeries', HorizontalAnchoredCategorySeries.$);
/**
 * @hidden
 */
export class PointSeriesView extends AnchoredCategorySeriesView {
    constructor(a) {
        super(a);
        this.c6 = null;
        this.c6 = a;
    }
    ap() {
        super.ap();
        if (!this.n) {
            this.by.l1 = 2;
            this.e.bj = 4;
        }
    }
    ac() {
        let a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.la = a;
        this.e.ev = 3;
        this.e.ew = 2;
        this.e.ex = 2;
        this.e.du = false;
    }
}
PointSeriesView.$t = markType(PointSeriesView, 'PointSeriesView', AnchoredCategorySeriesView.$);
